@@ -8,17 +8,12 @@ import click
 from phcontext.phcontextfacade import PhContextFacade
 
 
-@click.group()
-def phcli():
-    pass
-
-
-@phcli.command()
+@click.command()
 @click.option("--cmd", prompt="Your command is", help="The command that you want to process.",
               type=click.Choice(["create", "combine", "dag", "publish", "run", "submit", "status"]))
 @click.option("-p", "--path", prompt="Your config and python job file directory",
               help="The concert job you want the process.")
-@click.option("-c", "--context", default="")
+@click.option("-c", "--context", default="{}")
 def maxauto(cmd, path, context):
     """The Pharbers Max Job Command Line Interface (CLI)
 
